@@ -1,4 +1,7 @@
 """ Core main registry app settings
+
+Settings with the following syntax can be overwritten at the project level:
+SETTING_NAME = getattr(settings, "SETTING_NAME", "Default Value")
 """
 from os.path import join
 
